@@ -12,10 +12,10 @@ has _source_file_registry => sub { Sentry::SourceFileRegistry->new };
 has _home                 => sub { Mojo::Home->new->detect };
 
 sub _is_in_app ($self) {
-  return
-       $self->filename !~ /\.cpan\//
-    && index($self->filename, $Config{siteprefix}) == -1
-    && index($self->filename, $self->_home) > -1;
+  return substr($self->filename, 0, 1) ne '/'
+    || ( $self->filename !~ /\.cpan\//
+      && index($self->filename, $Config{siteprefix}) == -1
+      && index($self->filename, $self->_home) > -1);
 }
 
 sub _map_file_to_context ($self) {
